about summary refs log tree commit diff
path: root/sysdeps/generic/bits
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/generic/bits')
-rw-r--r--sysdeps/generic/bits/socket.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/sysdeps/generic/bits/socket.h b/sysdeps/generic/bits/socket.h
index d12d96cc14..af42dfac78 100644
--- a/sysdeps/generic/bits/socket.h
+++ b/sysdeps/generic/bits/socket.h
@@ -24,11 +24,14 @@
 
 #include <features.h>
 
-__BEGIN_DECLS
-
 #define	__need_size_t
 #include <stddef.h>
 
+__BEGIN_DECLS
+
+/* Type for length arguments in socket calls.  */
+typedef unsigned int socklen_t;
+
 
 /* Types of sockets.  */
 enum __socket_type
@@ -145,13 +148,15 @@ enum
 struct msghdr
   {
     __ptr_t msg_name;		/* Address to send to/receive from.  */
-    size_t msg_namelen;		/* Length of address data.  */
+    socklen_t msg_namelen;	/* Length of address data.  */
 
     struct iovec *msg_iov;	/* Vector of data to send/receive into.  */
-    size_t msg_iovlen;		/* Number of elements in the vector.  */
+    int msg_iovlen;		/* Number of elements in the vector.  */
 
     __ptr_t msg_accrights;	/* Access rights information.  */
-    size_t msg_accrightslen;	/* Length of access rights information.  */
+    socklen_t msg_accrightslen;	/* Length of access rights information.  */
+
+    int msg_flags;		/* Flags in received message.  */
   };